Module runtime

Module runtime 

Engine background runtime: enrich worker (09 3).

Current implementation is synchronous: enrich is executed immediately after write to complete strong semantic dimensions. Can later be upgraded to a tokio async background worker.

Functions

run_enrich_sync
Synchronously run enrich on a memory at the Indexed stage: completes goals/preferences/emotions/decisions (deterministic rules).